@@ -6,8 +6,10 @@ import (
 	"strings"
 	"testing"
 
+	// Using banydonk/yaml instead of the default yaml pkg because the default
+	// pkg incorrectly escapes unicode. https://github.com/go-yaml/yaml/issues/737
+	"github.com/braydonk/yaml"
 	"github.com/sethvargo/ratchet/resolver"
-	"gopkg.in/yaml.v3"
 )
 
 func TestCheck(t *testing.T) {
@@ -66,7 +68,7 @@ jobs:
 
 			m := helperStringToYAML(t, tc.in)
 
-			if err := Check(ctx, par, m); err != nil {
+			if err := Check(ctx, par, []*yaml.Node{m}); err != nil {
 				if tc.err == "" {
 					t.Fatal(err)
 				} else {
@@ -90,16 +92,22 @@ func TestPin(t *testing.T) {
 		"actions://good/repo@v0": {
 			Resolved: "good/repo@a12a3943",
 		},
+		"actions://good/repo@v1": {
+			Resolved: "good/repo@b12a3943",
+		},
 		"actions://good/repo/sub/path@v0": {
 			Resolved: "good/repo/sub/path@a12a3943",
 		},
+		"actions://good/repo/sub/path@v2": {
+			Resolved: "good/repo/sub/path@b12a3943",
+		},
 		"actions://good/repo@2541b1294d2704b0964813337f33b291d3f8596b": {
 			Resolved: "good/repo@2541b1294d2704b0964813337f33b291d3f8596b",
 		},
 		"container://ubuntu@sha256:47f14534bda344d9fe6ffd6effb95eefe579f4be0d508b7445cf77f61a0e5724": {
 			Resolved: "ubuntu@sha256:47f14534bda344d9fe6ffd6effb95eefe579f4be0d508b7445cf77f61a0e5724",
 		},
-	})
+	}, nil)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -208,7 +216,170 @@ jobs:
 
 			m := helperStringToYAML(t, tc.in)
 
-			if err := Pin(ctx, res, par, m, 2); err != nil {
+			if err := Pin(ctx, res, par, []*yaml.Node{m}, 2); err != nil {
+				if tc.err == "" {
+					t.Fatal(err)
+				} else {
+					if got, want := err.Error(), tc.err; !strings.Contains(got, want) {
+						t.Errorf("expected %q to contain %q", got, want)
+					}
+				}
+			} else if tc.err != "" {
+				t.Fatal("expected error, got nothing")
+			}
+
+			if tc.err == "" {
+				if got, want := helperYAMLToString(t, m), strings.TrimSpace(tc.exp); got != want {
+					t.Errorf("expected \n\n%s\n\nto be\n\n%s\n\n", got, want)
+				}
+			}
+		})
+	}
+}
+
+func TestUpgrade(t *testing.T) {
+	t.Parallel()
+
+	ctx := context.Background()
+
+	res, err := resolver.NewTest(nil,
+		map[string]*resolver.TestResult{
+			"actions://good/repo@v0": {
+				Resolved: "actions://good/repo@v2.1.0",
+			},
+			"actions://good/repo@v2.1.0": {
+				Resolved: "actions://good/repo@v2.1.0",
+			},
+			"actions://good/repo@a12a3943": {
+				Resolved: "actions://good/repo@v2.1.0",
+			},
+			"actions://good/repo/sub/path@a12a3943": {
+				Resolved: "actions://good/repo/sub/path@v2.1.0",
+			},
+		},
+	)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	par := new(Actions)
+
+	cases := []struct {
+		name string
+		in   string
+		exp  string
+		err  string
+	}{
+		{
+			name: "no_uses",
+			in: `
+foo: 'bar'
+`,
+			exp: `
+foo: 'bar'
+`,
+		},
+		{
+			name: "unpinned_old",
+			in: `
+jobs:
+  my_job:
+    steps:
+      - uses: 'good/repo@v0'
+`,
+			exp: `
+jobs:
+  my_job:
+    steps:
+      - uses: 'good/repo@v2.1.0' # ratchet:good/repo@v2.1.0
+`,
+		},
+		{
+			name: "unpinned_latest",
+			in: `
+jobs:
+  my_job:
+    steps:
+      - uses: 'good/repo@v2.1.0'
+`,
+			exp: `
+jobs:
+  my_job:
+    steps:
+      - uses: 'good/repo@v2.1.0' # ratchet:good/repo@v2.1.0
+`,
+		},
+		{
+			name: "pinned",
+			in: `
+jobs:
+  my_job:
+    steps:
+      - uses: 'good/repo@a12a3943'
+`,
+			exp: `
+jobs:
+  my_job:
+    steps:
+      - uses: 'good/repo@v2.1.0' # ratchet:good/repo@v2.1.0
+`,
+		},
+		{
+			name: "subpath",
+			in: `
+jobs:
+  my_job:
+    steps:
+      - uses: 'good/repo/sub/path@a12a3943'
+`,
+			exp: `
+jobs:
+  my_job:
+    steps:
+      - uses: 'good/repo/sub/path@v2.1.0' # ratchet:good/repo/sub/path@v2.1.0
+`,
+		},
+		{
+			name: "existing_comment",
+			in: `
+jobs:
+  my_job:
+    steps:
+      - uses: 'good/repo@v0' # this is a comment
+`,
+			exp: `
+jobs:
+  my_job:
+    steps:
+      - uses: 'good/repo@v2.1.0' # this is a comment ratchet:good/repo@v2.1.0
+		`,
+		},
+		{
+			name: "exclude",
+			in: `
+jobs:
+  my_job:
+    steps:
+      - uses: 'good/repo@v0' # ratchet:exclude # this is a comment
+`,
+			exp: `
+jobs:
+  my_job:
+    steps:
+      - uses: 'good/repo@v0' # ratchet:exclude # this is a comment
+		`,
+		},
+	}
+
+	for _, tc := range cases {
+		tc := tc
+
+		t.Run(tc.name, func(t *testing.T) {
+			t.Parallel()
+
+			m := helperStringToYAML(t, tc.in)
+
+			if err := Upgrade(ctx, res, par, []*yaml.Node{m}, 2); err != nil {
 				if tc.err == "" {
 					t.Fatal(err)
 				} else {
@@ -232,6 +403,8 @@ jobs:
 func TestUnpin(t *testing.T) {
 	t.Parallel()
 
+	ctx := context.Background()
+
 	cases := []struct {
 		name string
 		in   string
@@ -280,7 +453,7 @@ func TestUnpin(t *testing.T) {
 
 			m := helperStringToYAML(t, tc.in)
 
-			if err := Unpin(m); err != nil {
+			if err := Unpin(ctx, []*yaml.Node{m}); err != nil {
 				t.Fatal(err)
 			}
 
